@@ -59,7 +59,8 @@ def mi_request_programs(host: str, port: int, usr: str, pwd: str) -> requests.mo
 
     return request
 
-def mi_request_execute(host: str, port: int, usr: str, pwd:str, program: str, transaction: str, **kwargs) -> requests.models.Response:
+from typing import Optional
+def mi_request_execute(host: str, port: int, usr: str, pwd:str, program: str, transaction: str, **kwargs: Optional[dict]) -> requests.models.Response:
     param_str = dict_to_param_str(kwargs)
     url = f'http://{host}:{port}/m3api-rest/execute/{program}/{transaction}{param_str}'
     request = mi_request(url, usr, pwd)
